@@ -2,7 +2,7 @@
 #'
 #' @description Mean of euclidean nearest-neighbor distance (Aggregation metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick or a list of rasterLayers.
+#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
 #' @param directions The number of directions in which patches should be connected: 4 (rook's case) or 8 (queen's case).
 #' @param verbose Print warning message if not sufficient patches are present
 #'
@@ -51,81 +51,8 @@
 #' Ecological monographs, 65(3), 235-260.
 #'
 #' @export
-lsm_l_enn_mn <- function(landscape, directions, verbose) UseMethod("lsm_l_enn_mn")
-
-#' @name lsm_l_enn_mn
-#' @export
-lsm_l_enn_mn.RasterLayer <- function(landscape, directions = 8, verbose = TRUE) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_l_enn_mn_calc,
-                     directions = directions,
-                     verbose = verbose)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_l_enn_mn
-#' @export
-lsm_l_enn_mn.RasterStack <- function(landscape, directions = 8, verbose = TRUE) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_l_enn_mn_calc,
-                     directions = directions,
-                     verbose = verbose)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_l_enn_mn
-#' @export
-lsm_l_enn_mn.RasterBrick <- function(landscape, directions = 8, verbose = TRUE) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_l_enn_mn_calc,
-                     directions = directions,
-                     verbose = verbose)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_l_enn_mn
-#' @export
-lsm_l_enn_mn.stars <- function(landscape, directions = 8, verbose = TRUE) {
-
-    landscape <- methods::as(landscape, "Raster")
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_l_enn_mn_calc,
-                     directions = directions,
-                     verbose = verbose)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_l_enn_mn
-#' @export
-lsm_l_enn_mn.list <- function(landscape, directions = 8, verbose = TRUE) {
+lsm_l_enn_mn <- function(landscape, directions = 8, verbose = TRUE) {
+    landscape <- landscape_as_list(landscape)
 
     result <- lapply(X = landscape,
                      FUN = lsm_l_enn_mn_calc,
